[![Travis status](https://img.shields.io/travis/better/convoys/master.svg?style=flat)](https://travis-ci.org/better/convoys)
[![Coverage Status](https://img.shields.io/coveralls/better/convoys/master.svg?style=flat)](https://coveralls.io/github/better/convoys?branch=master)
[![PyPI version](https://img.shields.io/pypi/v/convoys.svg?style=flat)](https://pypi.org/project/convoys/)

Convoys
=======

![pic](docs/images/dob-violations-combined.png)

Convoys is a simple library that fits a few statistical model useful for modeling time-lagged conversions.
There is a lot more info if you head over to the  [documentation](https://better.engineering/convoys/).

Installation
------------

The easiest way right now is to install the latest version from PyPI:

```
pip install convoys
```

More info
---------

Convoys was built by [Erik Bernhardsson](https://github.com/erikbern) and has the MIT license.
